[coreboot] [flashrom] r581 - trunk

svn at coreboot.org svn at coreboot.org
Tue Jun 9 20:29:30 CEST 2009


Author: libv
Date: 2009-06-09 20:29:30 +0200 (Tue, 09 Jun 2009)
New Revision: 581

Modified:
   trunk/board_enable.c
Log:
Add board enable for Albatron PM266A boards.

There are multiple albatron pm266a boards which all share the same bios
image. This means that both the board enable and the subsystem ids are
exactly the same.

The board enable is the same as the epox EP-8K5A2, namely only raising
memw on the superio.

Signed-off-by: Luc Verhaegen <libv at skynet.be>
Acked-by: Ronald G. Minnich <rminnich at gmail.com>
Acked-by: Mateusz Murawski <matowy at tlen.pl>


Modified: trunk/board_enable.c
===================================================================
--- trunk/board_enable.c	2009-06-05 20:53:07 UTC (rev 580)
+++ trunk/board_enable.c	2009-06-09 18:29:30 UTC (rev 581)
@@ -270,7 +270,7 @@
 }
 
 /**
  * Suited for EPoX EP-8K5A2.
  */
 static int board_epox_ep_8k5a2(const char *name)
 {
@@ -685,6 +685,7 @@
 	/* first pci-id set [4],          second pci-id set [4],          coreboot id [2],             vendor name    board name            flash enable */
 	{0x8086, 0x1130,      0,      0,  0x105a, 0x0d30, 0x105a, 0x4d33, "acorp",      "6a815epd",    "Acorp",       "6A815EPD",           board_acorp_6a815epd},
 	{0x1022, 0x746B, 0x1022, 0x36C0,       0,      0,      0,      0, "AGAMI",      "ARUMA",       "agami",       "Aruma",              w83627hf_gpio24_raise_2e},
+	{0x1106, 0x3177, 0x17F2, 0x3177,  0x1106, 0x3148, 0x17F2, 0x3148, NULL,         NULL,          "Albatron",    "PM266A",             board_epox_ep_8k5a2},
 	{0x1022, 0x2090,      0,      0,  0x1022, 0x2080,      0,      0, "artecgroup", "dbe61",       "Artec Group", "DBE61",              board_artecgroup_dbe6x},
 	{0x1022, 0x2090,      0,      0,  0x1022, 0x2080,      0,      0, "artecgroup", "dbe62",       "Artec Group", "DBE62",              board_artecgroup_dbe6x},
 	{0x1106, 0x3177, 0x1043, 0x80A1,  0x1106, 0x3205, 0x1043, 0x8118, NULL,         NULL,          "ASUS",        "A7V8-MX SE",         board_asus_a7v8x_mx},
@@ -270,7 +270,7 @@
 
 /**
- * Suited for EPoX EP-8K5A2.
+ * Suited for EPoX EP-8K5A2 and Albatron PM266A.
  */
 static int board_epox_ep_8k5a2(const char *name)





More information about the coreboot mailing list